# Is Josh 18?

A command-line interface to determine if Josh is 18.


## Installation

    $ pip install isjosh18 --upgrade


## Usage

    $ isjosh18 -h


## Example

![Example](https://i.imgur.com/sCzdEW7.gif)
